/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.identitytoolkit.model;

import com.google.api.client.json.GenericJson;

/**
 * Request to get the IDP authentication URL.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Identity Toolkit API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class IdentitytoolkitRelyingpartyCreateAuthUriRequest extends GenericJson {

  /**
   * The relying party OAuth client ID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String clientId;

  /**
   * The opaque value used by the client to maintain context info between the authentication request
   * and the IDP callback.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String context;

  /**
   * The URI to which the IDP redirects the user after the federated login flow.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String continueUri;

  /**
   * The email or federated ID of the user.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String identifier;

  /**
   * Optional realm for OpenID protocol. The sub string "scheme://domain:port" of the param
   * "continueUri" is used if this is not set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String openidRealm;

  /**
   * The IdP ID. For white listed IdPs it's a short domain name e.g. google.com, aol.com, live.net
   * and yahoo.com. For other OpenID IdPs it's the OP identifier.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String providerId;

  /**
   * The relying party OAuth client ID.
   * The value returned may be {@code null}.
   */
  public String getClientId() {
    return clientId;
  }

  /**
   * The relying party OAuth client ID.
   * The value set may be {@code null}.
   */
  public IdentitytoolkitRelyingpartyCreateAuthUriRequest setClientId(String clientId) {
    this.clientId = clientId;
    return this;
  }

  /**
   * The opaque value used by the client to maintain context info between the authentication request
   * and the IDP callback.
   * The value returned may be {@code null}.
   */
  public String getContext() {
    return context;
  }

  /**
   * The opaque value used by the client to maintain context info between the authentication request
   * and the IDP callback.
   * The value set may be {@code null}.
   */
  public IdentitytoolkitRelyingpartyCreateAuthUriRequest setContext(String context) {
    this.context = context;
    return this;
  }

  /**
   * The URI to which the IDP redirects the user after the federated login flow.
   * The value returned may be {@code null}.
   */
  public String getContinueUri() {
    return continueUri;
  }

  /**
   * The URI to which the IDP redirects the user after the federated login flow.
   * The value set may be {@code null}.
   */
  public IdentitytoolkitRelyingpartyCreateAuthUriRequest setContinueUri(String continueUri) {
    this.continueUri = continueUri;
    return this;
  }

  /**
   * The email or federated ID of the user.
   * The value returned may be {@code null}.
   */
  public String getIdentifier() {
    return identifier;
  }

  /**
   * The email or federated ID of the user.
   * The value set may be {@code null}.
   */
  public IdentitytoolkitRelyingpartyCreateAuthUriRequest setIdentifier(String identifier) {
    this.identifier = identifier;
    return this;
  }

  /**
   * Optional realm for OpenID protocol. The sub string "scheme://domain:port" of the param
   * "continueUri" is used if this is not set.
   * The value returned may be {@code null}.
   */
  public String getOpenidRealm() {
    return openidRealm;
  }

  /**
   * Optional realm for OpenID protocol. The sub string "scheme://domain:port" of the param
   * "continueUri" is used if this is not set.
   * The value set may be {@code null}.
   */
  public IdentitytoolkitRelyingpartyCreateAuthUriRequest setOpenidRealm(String openidRealm) {
    this.openidRealm = openidRealm;
    return this;
  }

  /**
   * The IdP ID. For white listed IdPs it's a short domain name e.g. google.com, aol.com, live.net
   * and yahoo.com. For other OpenID IdPs it's the OP identifier.
   * The value returned may be {@code null}.
   */
  public String getProviderId() {
    return providerId;
  }

  /**
   * The IdP ID. For white listed IdPs it's a short domain name e.g. google.com, aol.com, live.net
   * and yahoo.com. For other OpenID IdPs it's the OP identifier.
   * The value set may be {@code null}.
   */
  public IdentitytoolkitRelyingpartyCreateAuthUriRequest setProviderId(String providerId) {
    this.providerId = providerId;
    return this;
  }

}
